==> jc-1.4.0.tar.gz: javax/security/auth/PrivateCredentialPermission__24CredOwner.h <==
// class javax.security.auth.PrivateCredentialPermission$CredOwner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 81951bba1c6aa3a javax_security_auth_PrivateCredentialPermission__24CredOwner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_PrivateCredentialPermission__24CredOwner_H_
#define _JC_javax_security_auth_PrivateCredentialPermission__24CredOwner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object;

typedef const struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype;

// Constructors
extern void _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$getPrincipalClass$e2538a41d7072aad(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$getPrincipalName$76d87956a7c11312(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *);
extern jint _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$getPrincipalClass$e2538a41d7072aad;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$getPrincipalName$76d87956a7c11312;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getPrincipalClass$e2538a41d7072aad)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *);
	struct _jc_java_lang_String$object	*(*getPrincipalName$76d87956a7c11312)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *);
};

// Vtable
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods	javax_security_auth_PrivateCredentialPermission__24CredOwner;
};

// Vtype
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype {
	_jc_type			type;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs {
	struct _jc_java_lang_String$object	*principalClass;
	struct _jc_java_lang_String$object	*principalName;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs {
    _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs	javax_security_auth_PrivateCredentialPermission__24CredOwner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs	javax_security_auth_PrivateCredentialPermission__24CredOwner;
};

// Object instance structure
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object {
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype	*vtype;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_PrivateCredentialPermission__24CredOwner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$class_object;

#endif	/* _JC_javax_security_auth_PrivateCredentialPermission__24CredOwner_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/PrivateCredentialPermission__24CredOwner.h <==
// class javax.security.auth.PrivateCredentialPermission$CredOwner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 81951bba1c6aa3a javax_security_auth_PrivateCredentialPermission__24CredOwner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_PrivateCredentialPermission__24CredOwner_H_
#define _JC_javax_security_auth_PrivateCredentialPermission__24CredOwner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object;

typedef const struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype;

// Constructors
extern void _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$getPrincipalClass$e2538a41d7072aad(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$getPrincipalName$76d87956a7c11312(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$getPrincipalClass$e2538a41d7072aad;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$getPrincipalName$76d87956a7c11312;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrincipalClass$e2538a41d7072aad)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrincipalName$76d87956a7c11312)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vmethods	javax_security_auth_PrivateCredentialPermission__24CredOwner;
};

// Vtype
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype {
	_jc_type			type;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs {
	struct _jc_java_lang_String$object	*principalClass;
	struct _jc_java_lang_String$object	*principalName;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs {
    _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_refs	javax_security_auth_PrivateCredentialPermission__24CredOwner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$sub_nonrefs	javax_security_auth_PrivateCredentialPermission__24CredOwner;
};

// Object instance structure
struct _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$object {
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype	*vtype;
	_jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$vtype _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_PrivateCredentialPermission__24CredOwner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_PrivateCredentialPermission__24CredOwner$class_object;

#endif	/* _JC_javax_security_auth_PrivateCredentialPermission__24CredOwner_H_ */
